diff --git a/Source/WebKit/chromium/WebKit.gyp b/Source/WebKit/chromium/WebKit.gyp
index 1eb6738..65d3c96 100644
--- a/Source/WebKit/chromium/WebKit.gyp
+++ b/Source/WebKit/chromium/WebKit.gyp
@@ -521,6 +521,22 @@
             ],
         },
         {
+            'target_name': 'decode_bench',
+            'type': 'executable',
+            'dependencies': [
+                '../../wtf/wtf.gyp:wtf',
+                '../../core/core.gyp:webcore',
+                'webkit_test_support',
+                'webkit',
+            ],
+            'defines': [
+                'WEBKIT_IMPLEMENTATION=1',
+            ],
+            'sources': [
+                'src/gif_decoder.cc',
+            ],
+        },
+        {
             'target_name': 'webkit_test_support',
             'conditions': [
                 ['component=="shared_library"', {
diff --git a/Source/WebKit/chromium/src/gif_decoder.cc b/Source/WebKit/chromium/src/gif_decoder.cc
new file mode 100644
index 0000000..3352b01
--- /dev/null
+++ b/Source/WebKit/chromium/src/gif_decoder.cc
@@ -0,0 +1,96 @@
+#include <iostream>
+#include <stdio.h>
+#include <time.h>
+
+#include "config.h"
+
+#include "RuntimeEnabledFeatures.h"
+#include "core/platform/image-decoders/ImageDecoder.h"
+#include "core/platform/EventTracer.h"
+#include "core/platform/FileSystem.h"
+#include "core/platform/PlatformInstrumentation.h"
+#include "core/platform/SharedBuffer.h"
+#include "public/web/WebKit.h"
+#include "public/platform/Platform.h"
+
+#include <wtf/OwnPtr.h>
+#include <wtf/PassOwnPtr.h>
+#include <wtf/Assertions.h>
+#include <wtf/MainThread.h>
+#include <wtf/Threading.h>
+#include <wtf/UnusedParam.h>
+#include <wtf/text/AtomicString.h>
+#include <wtf/CurrentTime.h>
+
+using namespace std;
+using namespace WebCore;
+
+static PassRefPtr<SharedBuffer> readFile(const char* fileName)
+{
+    FILE * file;
+
+    file = fopen (fileName, "rb");
+    if (!file)
+        exit(1);
+
+    // obtain file size:
+    fseek(file, 0, SEEK_END);
+    size_t size = ftell(file);
+    rewind(file);
+
+    // allocate memory to contain the whole file:
+    unsigned char* buffer = new unsigned char[size];
+    fread(buffer, 1, size, file);
+
+    return SharedBuffer::create(buffer, size);
+}
+
+class DummyWebKitPlatformSupport : public WebKit::Platform {
+  public:
+    ~DummyWebKitPlatformSupport() {}
+
+    virtual void cryptographicallyRandomValues(unsigned char* buffer, size_t length) {}
+    virtual const unsigned char* getTraceCategoryEnabledFlag(const char* categoryName) {
+        static const char disabled[] = "";
+        return (const unsigned char*)disabled;
+    }
+
+    DummyWebKitPlatformSupport() {}
+};
+
+class DummyPlatformInstrumentationClient : public PlatformInstrumentationClient {
+ public:
+  DummyPlatformInstrumentationClient() {}
+  virtual ~DummyPlatformInstrumentationClient() {}
+
+  virtual void willDecodeImage(const String& imageType) {}
+  virtual void didDecodeImage() {}
+  virtual void willResizeImage(bool shouldCache) {}
+  virtual void didResizeImage() {}
+};
+
+int main(int argc, char** argv) {
+    if (argc == 1) {
+        cout << "decode_bench [file]" << endl;
+        return 0;
+    }
+
+    WebKit::initializeWithoutV8(new DummyWebKitPlatformSupport());
+    WebCore::RuntimeEnabledFeatures::setAnimatedWebPEnabled(true);
+
+    RefPtr<SharedBuffer> data = readFile(argv[1]);
+
+    clock_t beginTime = clock();
+    for (int n = 0; n < 1000; ++n) {
+        OwnPtr<ImageDecoder> decoder = ImageDecoder::create(*data.get(), ImageSource::AlphaNotPremultiplied, ImageSource::GammaAndColorProfileApplied);
+        decoder->setData(data.get(), true);
+        int frames = decoder->frameCount();
+        for (int i = 0; i < frames; ++i) {
+            ImageFrame* frame = decoder->frameBufferAtIndex(i);
+            if (!frame)
+                continue;
+        }
+    }
+    cout << (clock() - beginTime) * 1000 / CLOCKS_PER_SEC << endl;
+    return 0;
+}
